intelmq.bots.collectors.rsync package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.rsync package

## Submodules

## intelmq.bots.collectors.rsync.collector_rsync module

`intelmq.bots.collectors.rsync.collector_rsync.` `BOT`

  alias of `intelmq.bots.collectors.rsync.collector_rsync.RsyncCollectorBot`

class `intelmq.bots.collectors.rsync.collector_rsync.` `RsyncCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect data with rsync from any resource rsync supports

  `file`: str = '<file>'
  `init`()
  `process`()
  `rate_limit`: int = 1000
  `rsync_path`: str = '<path>'
  `temp_directory`: str = '/opt/intelmq/var/lib/bots/rsync_collector'

## Module contents